<!-- A markdown formed message explaining we are deprecating this package and pointing to the new one. -->

# Deprecation Notice

Current package is deprecated and will not be maintained anymore. The implementation has been moved to leverage the new [AWS Landing Zone Accelerator solution](https://aws.amazon.com/solutions/implementations/landing-zone-accelerator-on-aws/) ([github](https://github.com/awslabs/landing-zone-accelerator-on-aws)).

# AWS Bootstrap Kit Overview  [![Mentioned in Awesome CDK](https://awesome.re/mentioned-badge.svg)](https://github.com/kolomied/awesome-cdk) ![badge npm version](https://img.shields.io/npm/v/aws-bootstrap-kit/latest)

This is a strongly opinionated CDK set of constructs built for companies looking to follow AWS best practices on Day 1 while setting their development and deployment environment on AWS.

Let's start small but with potential for future growth without adding tech debt.

## Getting started

Check our [examples repo](https://github.com/aws-samples/aws-bootstrap-kit-examples)

## Constructs

As of today we expose only one global package which expose a set of stacks and constructs to help you get started properly on AWS.

## Usage

1. install

   ```
   npm install aws-bootstrap-kit
   ```
2. Check the [Examples](https://github.com/aws-samples/aws-bootstrap-kit-examples) and [API Doc](./API.md) for more details

## Contributing

Check [CONTRIBUTING.md](./CONTRIBUTING.md))
